<div align="center">

<a href="https://deeploy.ml"><img src="./docs/content/img/logo-letters.png" width="250px"></a>

**Deeploy - Thoughtful Machine Learning Ops**

</br>Human involvement is essential in successful ML deployments. 
</br>Deeploy standardizes Deployment, Monitoring and Explainability of ML models.

[![PyPi license](https://img.shields.io/pypi/l/deeploy.svg?color=blue)](https://img.shields.io/pypi/l/deeploy.svg?color=blue)
[![PyPI version shields.io](https://img.shields.io/pypi/v/deeploy.svg)](https://img.shields.io/pypi/v/deeploy.svg)
[![CI](https://gitlab.com/deeploy-ml/deeploy-python-client/badges/master/pipeline.svg)](https://gitlab.com/deeploy-ml/deeploy-python-client/pipelines)

</div>

---
## Deeploy Python Client

Python client for interacting with Deeploy.

Documenation for this Python module can be found [here](https://deeploy-ml.gitlab.io/deeploy-python-client/).